/* ====================================================================
 * The Apache Software License, Version 1.1
 *
 * Copyright (c) 2002 The Apache Software Foundation.  All rights
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The names "Apache" and "Apache Software Foundation" and
 *    "Apache POI" must not be used to endorse or promote products
 *    derived from this software without prior written permission. For
 *    written permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    "Apache POI", nor may "Apache" appear in their name, without
 *    prior written permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Apache Software Foundation.  For more
 * information on the Apache Software Foundation, please see
 * <http://www.apache.org/>.
 */

package org.apache.poi.hssf.usermodel;

import org.apache.poi.hssf.model.Workbook;
import org.apache.poi.hssf.record.NameRecord;

/**   
 * High Level Represention of Print Titles (Repeating Rows/Columns)
 * <p>
 * Simply a proxy for HSSFName so only row/column references are retrieved.  It
 * is intended to change the implementation once the actual PTG/formula is
 * worked out for how both Row and Columns are represented.
 * @author Danny Mui (danny at muibros.com)
 */

public class HSSFPrintTitles extends HSSFName{
	private NameRecord name;
	private Workbook workbook;

	/** 
	 * Creates new HSSFPrintTitles called by HSSFWorkbook to create PrintTitles
	 * from scratch.
	 *
	 * @see org.apache.poi.hssf.usermodel.HSSFWorkbook#createName()
	 * @param name the Name Record
	 * @param book - lowlevel Workbook object associated with the sheet.
	 * @param book the Workbook 
	 */

	protected HSSFPrintTitles(Workbook workbook, NameRecord name) {
		super(workbook, name);
	}

	/**
	 * Returns the rows referenced by the Print Titles
	 * @return String
	 */
	public String getRowReference() {
		return super.getReference();
	}

	/**
	 * Returns the columns referenced by the Print Titles
	 * @return String
	 */
	public String getColReference() {
		return super.getReference();
	}

	/**
	 * Sets the reference for the columns to repeat when printing
	 * <p>
	 * <i>Only one type (Row or Column) supported at the moment</i>
	 * @param reference
	 */
	public void setColReference(String reference) {
		super.setReference(reference);
	}

	/**
	 * Sets the reference for the rows to repeat when printing
	 * <p>
	 * <i>Only one type (Row or Column) supported at the moment</i>
	 * @param reference
	 */
	public void setRowReference(String reference) {
		super.setReference(reference);
	}
}
