
/* ====================================================================
 * The Apache Software License, Version 1.1
 *
 * Copyright (c) 2002 The Apache Software Foundation.  All rights
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The names "Apache" and "Apache Software Foundation" and
 *    "Apache POI" must not be used to endorse or promote products
 *    derived from this software without prior written permission. For
 *    written permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    "Apache POI", nor may "Apache" appear in their name, without
 *    prior written permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Apache Software Foundation.  For more
 * information on the Apache Software Foundation, please see
 * <http://www.apache.org/>.
 */

package org.apache.poi.hssf.record.formula;

import junit.framework.TestCase;

import org.apache.poi.hssf.usermodel.HSSFSheet;
import org.apache.poi.hssf.usermodel.HSSFWorkbook;


/**
 * @author Danny Mui (danny at muibros.com)
 */
public class TestArea3DPtg
    extends TestCase {
    
    public TestArea3DPtg(String testName) {
        super(testName);
    }
    
    public static void main(java.lang.String[] args) {
        String filename = System.getProperty("HSSF.testdata.path");
        
        // assume andy is running this in the debugger
        if (filename == null)
        {
            if (args != null && args.length == 1) {
            System.setProperty(
                "HSSF.testdata.path",
                args[0]);
            } else {
                System.err.println("Geesh, no HSSF.testdata.path system " +
                          "property, no command line arg with the path "+
                          "what do you expect me to do, guess where teh data " +
                          "files are?  Sorry, I give up!");
                                   
            }
            
        }
        
        
        junit.textui.TestRunner.run(TestArea3DPtg.class);
    }
    
    /**
     * Make sure the ptg yields the correct value
     */
	public void testColOnly()
	{
		HSSFWorkbook wb = new HSSFWorkbook();
		HSSFSheet sheet = wb.createSheet("Sheet1");
		String sheetName = wb.getSheetName(0);
		Area3DPtg ptg = new Area3DPtg(sheetName+"!$A:$A", (short)0);
		
		byte[] output = new byte[ptg.getSize()];		
		byte[] expected = 	{
							(byte)0x3b,
							(byte)0x00,
							(byte)0x00,
							(byte)0x00,
							(byte)0x00,
							(byte)0xff,
							(byte)0xff,
							(byte)0x00,
							(byte)0x00,
							(byte)0x00,
							(byte)0x00
							};
		
		ptg.writeBytes(output, 0);
		 
		for (int i = 0; i < output.length; i++)
		{
			assertEquals("Output PTG at Index ["+i+"](zero-based)", expected[i], output[i]);
		}
		    
	}

	/**
	 * Make sure the ptg yields the correct value
	 */
	public void testRowOnly()
	{
		HSSFWorkbook wb = new HSSFWorkbook();
		HSSFSheet sheet = wb.createSheet("Sheet1");
		String sheetName = wb.getSheetName(0);
		Area3DPtg ptg = new Area3DPtg(sheetName+"!$1:$2", (short)0);
		
		byte[] output = new byte[ptg.getSize()];
		byte[] expected = 	{
							(byte)0x3b,
							(byte)0x00,
							(byte)0x00,
							(byte)0x00,
							(byte)0x00,
							(byte)0x01,
							(byte)0x00,
							(byte)0x00,
							(byte)0x00,
							(byte)0xff,
							(byte)0x00
							};
							
		ptg.writeBytes(output, 0);
		 
		for (int i = 0; i < output.length; i++)
		{
			assertEquals("Output PTG at Index ["+i+"](zero-based)", expected[i], output[i]);
		}
		
		
	}
    
}

